==> z3-tracker-0.9.4.tar.gz: z3-tracker-0.9.4/z3tracker/ruleset/vt8/dungeons.py <==
'''
Dungeons
'''

__all__ = 'LOCATIONS',


LOCATIONS = {
    'Castle Dungeons': {
        'type': 'drop', 'map': 'light', 'coord': (332, 290),
        'link': {
            "Zelda's Treasure": []}
    },
    'East Palace': {
        'type': 'dungeon', 'map': 'light', 'coord': (636, 251),
        'bossroad': 'East Palace Boss',
        'link': {}
    },
    'Desert Palace': {
        'type': 'dungeon', 'map': 'light', 'coord': (49, 528),
        'bossroad': 'Desert Palace Trap Room 1',
        'link': {}
    },
    'Mountain Tower': {
        'type': 'dungeon', 'map': 'light', 'coord': (372, 14),
        'bossroad': 'Mountain Tower Interior',
        'link': {}
    },
    'Castle Tower': {
        'type': 'dungeon', 'map': 'light', 'coord': (332, 244),
        'bossroad': 'Castle Tower Boss',
        'link': {}
    },
    'Dark Palace': {
        'type': 'dungeon', 'map': 'dark', 'coord': (629, 241),
        'bossroad': 'Dark Palace Gauntlet',
        'link': {}
    },
    'Swamp Palace': {
        'type': 'dungeon', 'map': 'dark', 'coord': (304, 600),
        'bossroad': 'Swamp Palace Gauntlet',
        'link': {}
    },
    'Skull Woods': {
        'type': 'dungeon', 'map': 'dark', 'coord': (20, 22),
        'bossroad': 'Skull Woods Gauntlet 1',
        'link': {}
    },
    "Thieves' Town": {
        'type': 'dungeon', 'map': 'dark', 'coord': (77, 301),
        'bossroad': "Thieves' Town Blind's Cell",
        'link': {}
    },
    'Ice Palace': {
        'type': 'dungeon', 'map': 'dark', 'coord': (523, 552),
        'bossroad': 'Ice Palace Boss Puzzle',
        'link': {}
    },
    'Misery Mire': {
        'type': 'dungeon', 'map': 'dark', 'coord': (43, 532),
        'bossroad': 'Misery Mire Gauntlet',
        'link': {}
    },
    'Turtle Rock': {
        'type': 'dungeon', 'map': 'dark', 'coord': (618, 33),
        'bossroad': 'Turtle Rock Boss Door',
        'link': {}
    },
    "Ganon's Tower": {
        'type': 'dungeon', 'map': 'dark', 'coord': (367, 14),
        'bossroad': "Ganon's Tower Lobby",
        'link': {}
    },
}

==> z3-tracker-0.9.5.tar.gz: z3-tracker-0.9.5/z3tracker/ruleset/vt8/dungeons.py <==
'''
Dungeons
'''

__all__ = 'LOCATIONS',


LOCATIONS = {
    'Castle Dungeons': {
        'type': 'drop', 'map': 'light', 'coord': (332, 290),
        'link': {
            "Zelda's Treasure": []}
    },
    'East Palace': {
        'type': 'dungeon', 'map': 'light', 'coord': (636, 251),
        'bossroad': 'East Palace Boss',
        'link': {}
    },
    'Desert Palace': {
        'type': 'dungeon', 'map': 'light', 'coord': (49, 528),
        'bossroad': 'Desert Palace Trap Room 1',
        'link': {}
    },
    'Mountain Tower': {
        'type': 'dungeon', 'map': 'light', 'coord': (372, 14),
        'bossroad': 'Mountain Tower Interior',
        'link': {}
    },
    'Castle Tower': {
        'type': 'dungeon', 'map': 'light', 'coord': (332, 244),
        'bossroad': 'Castle Tower Boss',
        'link': {}
    },
    'Dark Palace': {
        'type': 'dungeon', 'map': 'dark', 'coord': (629, 241),
        'bossroad': 'Dark Palace Gauntlet',
        'link': {}
    },
    'Swamp Palace': {
        'type': 'dungeon', 'map': 'dark', 'coord': (304, 600),
        'bossroad': 'Swamp Palace Gauntlet',
        'link': {}
    },
    'Skull Woods': {
        'type': 'dungeon', 'map': 'dark', 'coord': (20, 22),
        'bossroad': 'Skull Woods Gauntlet 1',
        'link': {}
    },
    "Thieves' Town": {
        'type': 'dungeon', 'map': 'dark', 'coord': (77, 301),
        'bossroad': "Thieves' Town Blind's Cell",
        'link': {}
    },
    'Ice Palace': {
        'type': 'dungeon', 'map': 'dark', 'coord': (523, 552),
        'bossroad': 'Ice Palace Boss',
        'link': {}
    },
    'Misery Mire': {
        'type': 'dungeon', 'map': 'dark', 'coord': (43, 532),
        'bossroad': 'Misery Mire Gauntlet',
        'link': {}
    },
    'Turtle Rock': {
        'type': 'dungeon', 'map': 'dark', 'coord': (618, 33),
        'bossroad': 'Turtle Rock Boss Door',
        'link': {}
    },
    "Ganon's Tower": {
        'type': 'dungeon', 'map': 'dark', 'coord': (367, 14),
        'bossroad': "Ganon's Tower Lobby",
        'link': {}
    },
}
